/*
 * file CcBranch.java
 *
 *
 * Licensed Materials - Property of IBM 
 * Restricted Materials of IBM  
 * 
 * com.ibm.rational.wvcm.stp.cc.CcBranch
 * 
 * (C) Copyright IBM Corporation 2009, 2011.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */


package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.PropertyNameList.PropertyName;
import javax.wvcm.WvcmException;

/**
 * <p>
 * A proxy for a ClearCase branch.
 * </p>
 * <p>
 * Branches are used in base ClearCase to enable parallel development. 
 * A branch is an object that specifies a linear sequence of versions of an element. 
 * Every element has one <b>main</b> branch, which represents the principal line of development, 
 * and may have multiple subbranches, each of which represents a separate line of development. 
 * For example, a project team may use the <b>main</b> branch for new development work while using a 
 * subbranch simultaneously for fixing a bug.
 * </p>
 * <p>
 * For more branch information, see the ClearCase "Guide to Managing Software Projects"
 * manual, and the cleartool man pages "mkbrtype" and "mkbranch".
 * </p>
 */
public interface CcBranch extends CcVobResource
{
    /**
     * The branch type of which this branch is an instance.
     * */
    PropertyName<CcBranchType> TYPE =
        new PropertyName<CcBranchType>(PROPERTY_NAMESPACE,
                                       "branch-type");

    /**
     * Get the value of this branch instance's {@link #TYPE} property.
     * 
     * @return branch instance's branch type
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    CcBranchType getType() throws WvcmException;
}
